import java.awt.*;
import java.awt.event.*;
import java.lang.Math;

public class DiamondRing extends Frame {
	/**
	 *  コンストラクタ
	 */
	public DiamondRing() {
		setSize(400, 300);
		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				System.exit(0);
			}
		});
	}
	
	/**
	 *  ダイアモンドリング描画
	 * @param g		グラフィックスオブジェクト
	 * 
	 * @param cx	中心点のX座標 
	 * @param cy	中心点のY座標
	 * @param r		半径
	 * @param n		分割数
	 */
	public static void drawDiamondRing(Graphics g, int cx, int cy, int r, int n) {
		int x1, y1, x2, y2;
		int i, j;
		double rad = Math.PI * (double)2.0 / (double)n;
		for(i = 0; i < n - 1; i++) {
			x1 = (int)((double)cx + (double)r * Math.cos(rad * (double)i) + (double)0.5);
			y1 = (int)((double)cy + (double)r * Math.sin(rad * (double)i) + (double)0.5);
			for(j = i + 1; j < n; j++) {
				x2 = (int)((double)cx + (double)r * Math.cos(rad * (double)j) + (double)0.5);
				y2 = (int)((double)cy + (double)r * Math.sin(rad * (double)j) + (double)0.5);
				g.drawLine(x1, y1, x2, y2);
			}
		}
	}
	
	/**
	 * ウィンドウの描画
	 * 
  * @param g		グラフィックスオブジェクト
	 */
	public void paint(Graphics g) {
		drawDiamondRing(g, 200, 150, 120, 16);
	}
	
	public static void main(String[] args) {
		Frame window = new DiamondRing();
		window.show();
	}
}